# pyxag

A hobby research project mixing up a bit of maths, algorithms, graphs and the like.

Wiki: https://github.com/daviddoret/pyxag/wiki

Source: https://github.com/daviddoret/pyxag

Package: https://pypi.org/project/pyxag/